@@ -70,7 +70,8 @@ def ldap_connect_gssapi(domain):
 # Main object model
 
 class ADManager:
-    def __init__(self, ldapconn, base=None):
+    def __init__(self, dnsdomain, ldapconn, base=None):
+        self.dnsdomain = dnsdomain
         self.ldapconn = ldapconn
         self.base = base
 
@@ -81,6 +82,7 @@ class ADManager:
         logger.info("Connected to {dnsHostName} ({defaultNamingContext})".format(**ldapinfo))
 
         ad = cls(
+                dnsdomain = dnsdomain,
                 ldapconn = ldapconn,
                 base = ldapinfo['defaultNamingContext'],
             )
