@@ -30,13 +30,16 @@ def connect_smtp(config):
     return s
 
 
-def try_send_email(config, mailto, subject, body):
+def try_send_email(config, mailto, subject, body, html=None):
     msg = EmailMessage()
     msg['From'] = config.smtp.email_from,
     msg['To'] = mailto
     msg['Subject'] = subject
     msg.set_content(body)
 
+    if html is not None:
+        msg.add_alternative(html, subtype='html')
+
     try:
         with connect_smtp(config) as srv:
             srv.send_message(msg)
